/* Last modified: December 3, 2013

*--------------------*
*      OVERVIEW      *
*--------------------*

This Stata code merges repeated cross-sections of the CPS-MORG into (1) an individual-linked (2 period) panel,
and (2) an unlinked repeat cross-section of the first (month 4) survey per individual.


*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: none

Files needed: 

CPS-MORG:   multiple, by year; save pattern is morg`year'.dta - from NBER - http://www.nber.org/data/morg.html

mw_state_monthly.dta - monthly minimum wage values by state


NOTE: See the DataSources.txt file for more information


*/

/*

This code will:

1) merge sequential years of the MORG based on: intmonth hhid state hhnum lineno

2) evaluate matches based on age sex race educ

3) drop bad matches

4) combine the matched MORG years into one (fairly large) file

*/

set more off

forv y=1979/2012 {
use morg`y' , clear       //      Make sure that you have renamed the files to use 4-digit years, first

keep if minsamp == 4

/* Fixes for consistency across years */
 
* Race
replace race = 3 if race > 2

* Age (plus 1 in time t+1 or month == 8)
replace age = age + 1  if minsamp == 8

* Education

gen educ = .
label variable educ "Education in years (or 13+)"
label define educ_label 0 "Kindergarden or less" 4 "1-4 years" 6 "5-6 years" 8 "7-8 years" ///
9 "Ninth grade" 10 "Tenth grade" 11 "Eleventh grade" 12 "12th grade" 13 "More than 12th grade"
label values educ educ_label

if year <=  1991 {

  * Years of schooling

    gen edu = gradeat

  * Subtract one year if the highest grade attended is not completed (grdcom == 2)

    replace edu = edu - 1 if gradecp == 2 & edu >= 1
    
    replace educ = 0 if edu == 0
    replace educ = 4 if edu >= 1 & edu <= 4
    replace educ = 6 if edu >= 5 & edu <= 6
    replace educ = 8 if edu >= 7 & edu <= 8
    replace educ = 9 if edu == 9
    replace educ = 10 if edu == 10
    replace educ = 11 if edu == 11
    replace educ = 12 if edu == 12
    replace educ = 13 if edu >= 13
    
    drop edu
    
}
    
if year >= 1992 {

    replace educ = 0 if grade92 == 31
    replace educ = 4 if grade92 == 32
    replace educ = 6 if grade92 == 33
    replace educ = 8 if grade92 == 34
    replace educ = 9 if grade92 == 35
    replace educ = 10 if grade92 == 36
    replace educ = 11 if grade92 == 37
    replace educ = 12 if grade92 == 38
    replace educ = 13 if grade92 >= 39
    
    drop grade92
    
}


* Relationship to Household head

if year <= 1988 {

gen relate = .
replace relate = 1 if relahh == 1
replace relate = 2 if relahh == 2
replace relate = 3 if relahh == 3
replace relate = 4 if relahh == 4
replace relate = 5 if relahh == 5
replace relate = 6 if relahh == 6
}

if year >= 1989 & year <= 1993 {

gen relate = .
replace relate = 1 if relaref == 1
replace relate = 2 if relaref == 2
replace relate = 3 if relaref == 3
replace relate = 3 if relaref == 4
replace relate = 4 if relaref == 5
replace relate = 4 if relaref == 6
replace relate = 4 if relaref == 7
replace relate = 4 if relaref == 8
replace relate = 5 if relaref == 9
replace relate = 6 if relaref == 10
}

if year == 1994 {

gen relate = .
replace relate = 1 if relref94 == 1
replace relate = 2 if relref94 == 2
replace relate = 3 if relref94 == 3
replace relate = 4 if relref94 == 4
replace relate = 4 if relref94 == 5
replace relate = 4 if relref94 == 6
replace relate = 4 if relref94 == 7
replace relate = 4 if relref94 == 8
replace relate = 4 if relref94 == 9
replace relate = 5 if relref94 == 10
replace relate = 6 if relref94 == 12
replace relate = 6 if relref94 == 11
}

if year >= 1995 {

gen relate = .
replace relate = 1 if relref95 == 1
replace relate = 2 if relref95 == 2
replace relate = 3 if relref95 == 3
replace relate = 4 if relref95 == 4
replace relate = 4 if relref95 == 5
replace relate = 4 if relref95 == 6
replace relate = 4 if relref95 == 7
replace relate = 4 if relref95 == 8
replace relate = 4 if relref95 == 9
replace relate = 5 if relref95 == 10
replace relate = 6 if relref95 == 12
replace relate = 6 if relref95 == 11
replace relate = 5 if relref95 == 13
replace relate = 6 if relref95 == 14
replace relate = 5 if relref95 == 15
replace relate = 6 if relref95 == 16
replace relate = 5 if relref95 == 17
replace relate = 6 if relref95 == 18
}

label variable relate "Relationship of individual to HH head"
label define relate_lab 1 "Head with other relatives" 2 "Head with no other relatives" 3 "Spouse of head" ///
4 "Other relative of head" 5 "Non-relative of head with own relatives present" 6 "Non-relative of head with no relatives"
label values relate relate_lab


* Full-time / part-time status

gen byte fullpartnone = .

if year <= 1988 {

replace fullpartnone = 0 if ftpt79 == 0
replace fullpartnone = 3 if ftpt79 == 1
replace fullpartnone = 2 if ftpt79 == 2
replace fullpartnone = 2 if ftpt79 == 4
replace fullpartnone = 1 if ftpt79 == 3
replace fullpartnone = 1 if ftpt79 == 5
}

if year >= 1989 & year <= 1993 {
replace fullpartnone = 0 if ftpt89 == 1
replace fullpartnone = 3 if ftpt89 == 2
replace fullpartnone = 2 if ftpt89 == 3
replace fullpartnone = 2 if ftpt89 == 4
replace fullpartnone = 2 if ftpt89 == 5
replace fullpartnone = 1 if ftpt89 == 6
replace fullpartnone = 1 if ftpt89 == 7
}

if year >= 1994 {
replace fullpartnone = 0 if ftpt94 == 1
replace fullpartnone = 3 if ftpt94 == 2
replace fullpartnone = 2 if ftpt94 == 3
replace fullpartnone = 2 if ftpt94 == 7
replace fullpartnone = 2 if ftpt94 == 6
replace fullpartnone = 1 if ftpt94 == 11
replace fullpartnone = 1 if ftpt94 == 12
replace fullpartnone = 3 if ftpt94 == 5
replace fullpartnone = 2 if ftpt94 == 4
replace fullpartnone = 3 if ftpt94 == 8
replace fullpartnone = 3 if ftpt94 == 9
replace fullpartnone = 2 if ftpt94 == 10
}

label variable fullpartnone "Full or part time status or nilf"
label define ftn 0 "Not in labor force"
label define ftn 1 "Unemployed",add
label define ftn 2 "Part-time employed",add
label define ftn 3 "Full-time employed",add
label values fullpartnone ftn
drop if missing(fullpartnone)
drop ftpt*


/*     End of Fixes                   */


* Keep only variables needed (note that some of these change names by year)

// Same in all years: intmonth hhid state hhnum lineno age race sex weight uhourse paidhre earnhre earnwke
// Same that this code created: fullpartnone educ relate

keep intmonth hhid state hhnum lineno age race sex weight uhourse paidhre earnhre earnwke fullpartnone educ relate dind*

duplicates drop intmonth state hhid hhnum lineno,force

compress
sort intmonth state hhid hhnum lineno

save morg`y'_t,replace

}

forv y= 1980/2012 {

local x=`y'-1
use morg`y'

keep if minsamp == 8

/* Fixes for consistency across years */
 
* Race
replace race = 3 if race > 2

* Education

gen educ = .
label variable educ "Education in years (or 13+)"
label define educ_label 0 "Kindergarden or less" 4 "1-4 years" 6 "5-6 years" 8 "7-8 years" ///
9 "Ninth grade" 10 "Tenth grade" 11 "Eleventh grade" 12 "12th grade" 13 "More than 12th grade"
label values educ educ_label

if year <= 1991 {

  * Years of schooling

    gen edu = gradeat

  * Subtract one year if the highest grade attended is not completed (grdcom == 2)

    replace edu = edu - 1 if gradecp == 2 & edu >= 1
    
    replace educ = 0 if edu == 0
    replace educ = 4 if edu >= 1 & edu <= 4
    replace educ = 6 if edu >= 5 & edu <= 6
    replace educ = 8 if edu >= 7 & edu <= 8
    replace educ = 9 if edu == 9
    replace educ = 10 if edu == 10
    replace educ = 11 if edu == 11
    replace educ = 12 if edu == 12
    replace educ = 13 if edu >= 13
    
    drop edu
    
}
    
if year >= 1992 {

    replace educ = 0 if grade92 == 31
    replace educ = 4 if grade92 == 32
    replace educ = 6 if grade92 == 33
    replace educ = 8 if grade92 == 34
    replace educ = 9 if grade92 == 35
    replace educ = 10 if grade92 == 36
    replace educ = 11 if grade92 == 37
    replace educ = 12 if grade92 == 38
    replace educ = 13 if grade92 >= 39
    
    drop grade92
    
}


* Relationship to Household head

if year <= 1988 {

gen relate = .
replace relate = 1 if relahh == 1
replace relate = 2 if relahh == 2
replace relate = 3 if relahh == 3
replace relate = 4 if relahh == 4
replace relate = 5 if relahh == 5
replace relate = 6 if relahh == 6
}

if year >= 1989 & year <= 1993 {

gen relate = .
replace relate = 1 if relaref == 1
replace relate = 2 if relaref == 2
replace relate = 3 if relaref == 3
replace relate = 3 if relaref == 4
replace relate = 4 if relaref == 5
replace relate = 4 if relaref == 6
replace relate = 4 if relaref == 7
replace relate = 4 if relaref == 8
replace relate = 5 if relaref == 9
replace relate = 6 if relaref == 10
}

if year == 1994 {

gen relate = .
replace relate = 1 if relref94 == 1
replace relate = 2 if relref94 == 2
replace relate = 3 if relref94 == 3
replace relate = 4 if relref94 == 4
replace relate = 4 if relref94 == 5
replace relate = 4 if relref94 == 6
replace relate = 4 if relref94 == 7
replace relate = 4 if relref94 == 8
replace relate = 4 if relref94 == 9
replace relate = 5 if relref94 == 10
replace relate = 6 if relref94 == 12
replace relate = 6 if relref94 == 11
}

if year >= 1995 {

gen relate = .
replace relate = 1 if relref95 == 1
replace relate = 2 if relref95 == 2
replace relate = 3 if relref95 == 3
replace relate = 4 if relref95 == 4
replace relate = 4 if relref95 == 5
replace relate = 4 if relref95 == 6
replace relate = 4 if relref95 == 7
replace relate = 4 if relref95 == 8
replace relate = 4 if relref95 == 9
replace relate = 5 if relref95 == 10
replace relate = 6 if relref95 == 12
replace relate = 6 if relref95 == 11
replace relate = 5 if relref95 == 13
replace relate = 6 if relref95 == 14
replace relate = 5 if relref95 == 15
replace relate = 6 if relref95 == 16
replace relate = 5 if relref95 == 17
replace relate = 6 if relref95 == 18
}

label variable relate "Relationship of individual to HH head"
label define relate_lab 1 "Head with other relatives" 2 "Head with no other relatives" 3 "Spouse of head" ///
4 "Other relative of head" 5 "Non-relative of head with own relatives present" 6 "Non-relative of head with no relatives"
label values relate relate_lab


* Full-time / part-time status

gen byte fullpartnone = .

if year <= 1988 {

replace fullpartnone = 0 if ftpt79 == 0
replace fullpartnone = 3 if ftpt79 == 1
replace fullpartnone = 2 if ftpt79 == 2
replace fullpartnone = 2 if ftpt79 == 4
replace fullpartnone = 1 if ftpt79 == 3
replace fullpartnone = 1 if ftpt79 == 5
}

if year >= 1989 & year<= 1993 {

replace fullpartnone = 0 if ftpt89 == 1
replace fullpartnone = 3 if ftpt89 == 2
replace fullpartnone = 2 if ftpt89 == 3
replace fullpartnone = 2 if ftpt89 == 4
replace fullpartnone = 2 if ftpt89 == 5
replace fullpartnone = 1 if ftpt89 == 6
replace fullpartnone = 1 if ftpt89 == 7
}

if year >= 1994 {

replace fullpartnone = 0 if ftpt94 == 1
replace fullpartnone = 3 if ftpt94 == 2
replace fullpartnone = 2 if ftpt94 == 3
replace fullpartnone = 2 if ftpt94 == 7
replace fullpartnone = 2 if ftpt94 == 6
replace fullpartnone = 1 if ftpt94 == 11
replace fullpartnone = 1 if ftpt94 == 12
replace fullpartnone = 3 if ftpt94 == 5
replace fullpartnone = 2 if ftpt94 == 4
replace fullpartnone = 3 if ftpt94 == 8
replace fullpartnone = 3 if ftpt94 == 9
replace fullpartnone = 2 if ftpt94 == 10
}

label variable fullpartnone "Full or part time status or nilf"
label define ftn 0 "Not in labor force"
label define ftn 1 "Unemployed",add
label define ftn 2 "Part-time employed",add
label define ftn 3 "Full-time employed",add
label values fullpartnone ftn
drop if missing(fullpartnone)
drop ftpt*


/*     End of Fixes                   */


* Keep only variables needed (note that some of these change names by year)

// Same in all years: intmonth hhid state hhnum lineno age race sex weight uhourse paidhre earnhre earnwke
// Same that this code created: fullpartnone educ relate

keep intmonth hhid state hhnum lineno age race sex weight uhourse paidhre earnhre earnwke fullpartnone educ relate dind*

foreach var in age race sex weight uhourse paidhre earnhre earnwke fullpartnone educ relate dind* {
rename `var' `var'2
}

*duplicates drop intmonth state hhid hhnum lineno,force // I'll just do this in the time "t" and merge 1:m to improve (slightly) match rate

compress
sort intmonth state hhid hhnum lineno

save morg`x'_tplus1,replace

}




**********

* COMBINE

**********


set more off
forv y=1979/2011 { 

use morg`y'_t , clear

merge 1:m state hhid hhnum intmonth lineno using morg`y'_tplus1

foreach var in age race sex educ {
gen diff`var' = `var'2 - `var'
}

keep if _merge == 3 & diffsex == 0 & diffrace == 0 & diffeduc >= -1 & diffeduc <= 2 & diffage >= -1 & diffage <= 2
duplicates drop

egen long temphhid = group(state hhid hhnum intmonth)

keep intmonth state age race sex weight weight2 uhourse paidhre earnhre earnwke educ educ2 relate fullpartnone ///
uhourse2 paidhre2 earnhre2 earnwke2 fullpartnone2 temphhid dind*
gen year = `y'
order year , before(state)
label variable year "First year in which person was interviewed"
gen long hhid = `y' * 1000000 + temphhid
label variable hhid "Household id (unique to household)"
sort hhid age
gen long tempn = _n
gen long pid = `y' * 1000000 + tempn
label variable pid "Unique person id"
drop tempn temphhid

compress
save personmerged`y' , replace

}

set more off
use personmerged1979 , clear

forv y=1980/2011 {
append using personmerged`y'
}

gen statefips = .
label variable statefip "State (FIPS code)"
replace statefips = 1 if state == 63
replace statefips = 2 if state == 94
replace statefips = 4 if state == 86
replace statefips = 5 if state == 71
replace statefips = 6 if state == 93
replace statefips = 8 if state == 84
replace statefips = 9 if state == 16
replace statefips = 10 if state == 51
replace statefips = 11 if state == 53
replace statefips = 12 if state == 59
replace statefips = 13 if state == 58
replace statefips = 15 if state == 95
replace statefips = 16 if state == 82
replace statefips = 17 if state == 33
replace statefips = 18 if state == 32
replace statefips = 19 if state == 42
replace statefips = 20 if state == 47
replace statefips = 21 if state == 61
replace statefips = 22 if state == 72
replace statefips = 23 if state == 11
replace statefips = 24 if state == 52
replace statefips = 25 if state == 14
replace statefips = 26 if state == 34
replace statefips = 27 if state == 41
replace statefips = 28 if state == 64
replace statefips = 29 if state == 43
replace statefips = 30 if state == 81
replace statefips = 31 if state == 46
replace statefips = 32 if state == 88
replace statefips = 33 if state == 12
replace statefips = 34 if state == 22
replace statefips = 35 if state == 85
replace statefips = 36 if state == 21
replace statefips = 37 if state == 56
replace statefips = 38 if state == 44
replace statefips = 39 if state == 31
replace statefips = 40 if state == 73
replace statefips = 41 if state == 92
replace statefips = 42 if state == 23
replace statefips = 44 if state == 15
replace statefips = 45 if state == 57
replace statefips = 46 if state == 45
replace statefips = 47 if state == 62
replace statefips = 48 if state == 74
replace statefips = 49 if state == 87
replace statefips = 50 if state == 13
replace statefips = 51 if state == 54
replace statefips = 53 if state == 91
replace statefips = 54 if state == 55
replace statefips = 55 if state == 35
replace statefips = 56 if state == 83

label define fips 0 "Federal (FLSA)"

label define fips 1 "Alabama",add
label define fips 2 "Alaska",add
label define fips 4 "Arizona",add
label define fips 5 "Arkansas",add
label define fips 6 "California",add
label define fips 8 "Colorado",add
label define fips 9 "Connecticut",add
label define fips 10 "Delaware",add
label define fips 11 "District of Columbia",add
label define fips 12 "Florida",add
label define fips 13 "Georgia",add
label define fips 15 "Hawaii",add
label define fips 16 "Idaho",add
label define fips 17 "Illinois",add
label define fips 18 "Indiana",add
label define fips 19 "Iowa",add
label define fips 20 "Kansas",add
label define fips 21 "Kentucky",add
label define fips 22 "Louisiana",add
label define fips 23 "Maine",add
label define fips 24 "Maryland",add
label define fips 25 "Massachusetts",add
label define fips 26 "Michigan",add
label define fips 27 "Minnesota",add
label define fips 28 "Mississippi",add
label define fips 29 "Missouri",add
label define fips 30 "Montana",add
label define fips 31 "Nebraska",add
label define fips 32 "Nevada",add
label define fips 33 "New Hampshire",add
label define fips 34 "New Jersey",add
label define fips 35 "New Mexico",add
label define fips 36 "New York",add
label define fips 37 "North Carolina",add
label define fips 38 "North Dakota",add
label define fips 39 "Ohio",add
label define fips 40 "Oklahmma",add
label define fips 41 "Oregon",add
label define fips 42 "Pennsylvania",add
label define fips 44 "Rhode Island",add
label define fips 45 "South Carolina",add
label define fips 46 "South Dakota",add
label define fips 47 "Tennessee",add
label define fips 48 "Texas",add
label define fips 49 "Utah",add
label define fips 50 "Vermont",add
label define fips 51 "Virginia",add
label define fips 53 "Washington",add
label define fips 54 "West Virginia",add
label define fips 55 "Wisconsin",add
label define fips 56 "Wyoming",add
label values statefip fips

drop state

rename intmonth month
sort state year month
order statefips year month

merge m:1 state year month using mw_state_monthly
keep if _merge == 3 // Note that this keeps years 1979-2011
drop _merge realfedmw fedmw indexedwage eversuperfed lnmin quarter

rename mw mw1
rename realmw realmw1

replace year = year + 1
merge m:1 state year month using mw_state_monthly
keep if _merge == 3 // Note that this keeps years 1980-2012
drop _merge realfedmw fedmw indexedwage eversuperfed lnmin quarter

replace year = year - 1

rename mw mw2
rename realmw realmw2
rename mw1 mw
rename realmw1 realmw

sort statefips year hhid pid


#delimit ;
label values dind    dind ;  
label values dind2   dind ; 
label define dind    
	1           "Agriculture Service"           
	2           "Other Agriculture"             
	3           "Mining"                        
	4           "Construction"                  
	5           "Lumber and wood products , except furniture"
	6           "Furniture and fixtures"        
	7           "Stone clay ,glass and concrete product"
	8           "Primary metals"                
	9           "Fabricated metal"              
	10          "Not specified metal industries"
	11          "Machinery, except electrical"  
	12          "Electrical Machinery, equipment ,and supplies"
	13          "Motor vehicles and equipment"  
	14          "Aircrafts and parts"           
	15          "Other transportation equipment"
	16          "Professional and photographic equipment"
	17          "Toys, amusements ,and sporting goods"
	18          "Miscellaneous and not specified manufacturing industries"
	19          "Food and kindred products"     
	20          "Tobacco manufactures"          
	21          "Textile mill products"         
	22          "Apparel and other finished textile prod."
        23          "Paper and allied products"
	24          "Printing ,publishing and allied industries"
	25          "Chemicals and allied products" 
	26          "Petroleum and coal products"   
	27          "Rubber and miscellaneous plastics products"
	28          "Leather and leather products"  
	29          "Transportation"                
	30          "Communications"                
	31          "Utilities and Sanitary Services"
	32          "Wholesale Trade"               
	33          "Retail Trade"                  
	34          "Banking and Other Finance"     
	35          "Insurance and Real Estate"     
	36          "Private Household Services"    
	37          "Business Services"             
	38          "Repair Services"               
	39          "Personal Services , Except Private Household"
	40          "Entertainment and Recreation Services"
	41          "Hospitals"                     
	42          "Health Services , Except Hospitals"
	43          "Educational Services"          
	44          "Social Services"               
	45          "Other professional Services"   
	46          "Forestry and Fisheries"        
	51          "Armed Forces last job, currently unemployed"
	52          "Public Administration"         
;

label values dind02    dind02 ;  
label values dind022   dind02 ; 
label define dind02    
        1            "Agriculture"
        2            "Forestry, logging, fishing, hunting, and trapping"
        3            "Mining"
        4            "Construction"
        5            "Nonmetallic mineral products"
        6            "Primary metals and fabricated metal products"
        7            "Machinery manufacturing"
        8            "Computer and electronic products"
        9            "Electrical equipment, appliance manufacturing"
        10           "Transportation equipment manufacturing"
        11           "Wood products"
        12           "Furniture and fixtures manufacturing"
        13           "Miscellaneous and not specified manufacturing"
        14           "Food manufacturing"
        15           "Beverage and tobacco products"
        16           "Textile, apparel, and leather manufacturing"
        17           "Paper and printing"
        18           "Petroleum and coal products"
        19           "Chemical manufacturing"
        20           "Plastics and rubber products"
        21           "Wholesale trade"
        22           "Retail trade"
        23           "Transportation and warehousing"
        24           "Utilities"
        25           "Publishing industries (except internet)"
        26           "Motion picture and sound recording industries"
        27           "Broadcasting (except internet)"
        28           "Internet publishing and broadcasting"
        29           "Telecommunications"
        30           "Internet service providers and data processing services"
        31           "Other information services"
        32           "Finance"
        33           "Insurance"
        34           "Real Estate"
        35           "Rental and leasing services"
        36           "Professional and Technical services"
        37           "Management of companies and enterprises"
        38           "Administrative and support services"
        39           "Waste management and remediation services"
        40           "Educational services"
        41           "Hospitals"
        42           "Health care services , except hospitals"
        43           "Social assistance"
        44           "Arts, entertainment, and recreation"
        45           "Accomodation"
        46           "Food services and drinking places"
        47           "Repair and maintenance"
        48           "Personal and laundry services"
        49           "Membership associations and organizations"
        50           "Private households"
        51           "Public Administration"
        52           "Armed forces"
;

#delimit cr

label variable dind "NBER industry code for pre-2002"
label variable dind2 "NBER industry code for pre-2002"

label variable dind02 "NBER industry code for post-2002"
label variable dind022 "NBER industry code for post-2002"


order statefips censusreg censusdiv year month hhid pid relate age race sex ///
weight dind dind02 uhourse paidhre earnhre earnwke educ fullpartnone mw realmw ///
weight2 dind2 dind022 uhourse2 paidhre2 earnhre2 earnwke2 educ2 fullpartnone2 mw2 realmw2

label define howpaid 1 "Yes" 2 "No"
label values paidhre howpaid
label values paidhre2 howpaid

replace earnhre = earnhre / 100 if earnhre != .
replace earnhre2 = earnhre2 / 100 if earnhre2 != .

gen byte lemw = 0 if paidhre == 1
replace lemw = 1 if earnhre < mw
label variable lemw "Hourly worker is paid less than state minimum wage"
gen byte atmw = 0 if paidhre == 1
replace atmw = 1 if earnhre == mw
label variable atmw "Hourly worker is paid exactly state minimum wage"
gen byte leatmw = 0 if paidhre == 1
replace leatmw = 1 if earnhre <= mw
label variable leatmw "Hourly worker is paid less than or equal state MW"
gen byte mwp50 = 0 if paidhre == 1
replace mwp50 = 1 if earnhre <= mw + 0.5
label variable mwp50 "Hourly worker is paid within 50c of state MW"
gen byte mwp100 = 0 if paidhre == 1
replace mwp100 = 1 if earnhre <= mw +1.0
label variable mwp100 "Hourly worker is paid within 1 dollar of state MW"

gen leatmw_employed = 0 if fullpartnone > 1
replace leatmw_employed = 1 if leatmw_employed == 0 & leatmw == 1
label variable leatmw_employed "Worker is paid less than or equal state MW (all employed but not imputed)"

gen byte lemw2 = 0 if paidhre2 == 1
replace lemw2 = 1 if earnhre2 < mw2
label variable lemw2 "Hourly worker is paid less than state minimum wage"
gen byte atmw2 = 0 if paidhre2 == 1
replace atmw2 = 1 if earnhre2 == mw2
label variable atmw2 "Hourly worker is paid exactly state minimum wage"
gen byte leatmw2 = 0 if paidhre2 == 1
replace leatmw2=1 if earnhre2 <= mw2
label variable leatmw2 "Hourly worker is paid less than or equal state MW"
gen byte mwp50_2 = 0 if paidhre2 == 1
replace mwp50_2 = 1 if earnhre2 <= mw2 + 0.5
label variable mwp50_2 "Hourly worker is paid within 50c of state MW"
gen byte mwp100_2 = 0 if paidhre2 == 1
replace mwp100_2 = 1 if earnhre2 <= mw2 + 1.0
label variable mwp100_2 "Hourly worker is paid within 1 dollar of state MW"

gen leatmw2_employed = 0 if fullpartnone2 > 1
replace leatmw2_employed = 1 if leatmw2_employed == 0 & leatmw2 == 1
label variable leatmw2_employed "Worker is paid less than or equal state MW (all employed)"

compress
save linked_morg,replace

// Create an "un"linked version of sample month 4 only (to avoid duplicates on the same person) for broader statistics

set more off

use morg1979_t , clear
gen year = 1979
forv y = 1980/2012 {
append using morg`y'_t
replace year = `y' if year == .
}

order year intmonth hhid hhnum lineno , after(state)
label variable year "First year in which person was interviewed"

label define howpaid 1 "Yes" 2 "No"
label values paidhre howpaid

replace earnhre=earnhre/100 if earnhre! = .

gen statefips = .
label variable statefips "State (FIPS code)"
replace statefips = 1 if state == 63
replace statefips = 2 if state == 94
replace statefips = 4 if state == 86
replace statefips = 5 if state == 71
replace statefips = 6 if state == 93
replace statefips = 8 if state == 84
replace statefips = 9 if state == 16
replace statefips = 10 if state == 51
replace statefips = 11 if state == 53
replace statefips = 12 if state == 59
replace statefips = 13 if state == 58
replace statefips = 15 if state == 95
replace statefips = 16 if state == 82
replace statefips = 17 if state == 33
replace statefips = 18 if state == 32
replace statefips = 19 if state == 42
replace statefips = 20 if state == 47
replace statefips = 21 if state == 61
replace statefips = 22 if state == 72
replace statefips = 23 if state == 11
replace statefips = 24 if state == 52
replace statefips = 25 if state == 14
replace statefips = 26 if state == 34
replace statefips = 27 if state == 41
replace statefips = 28 if state == 64
replace statefips = 29 if state == 43
replace statefips = 30 if state == 81
replace statefips = 31 if state == 46
replace statefips = 32 if state == 88
replace statefips = 33 if state == 12
replace statefips = 34 if state == 22
replace statefips = 35 if state == 85
replace statefips = 36 if state == 21
replace statefips = 37 if state == 56
replace statefips = 38 if state == 44
replace statefips = 39 if state == 31
replace statefips = 40 if state == 73
replace statefips = 41 if state == 92
replace statefips = 42 if state == 23
replace statefips = 44 if state == 15
replace statefips = 45 if state == 57
replace statefips = 46 if state == 45
replace statefips = 47 if state == 62
replace statefips = 48 if state == 74
replace statefips = 49 if state == 87
replace statefips = 50 if state == 13
replace statefips = 51 if state == 54
replace statefips = 53 if state == 91
replace statefips = 54 if state == 55
replace statefips = 55 if state == 35
replace statefips = 56 if state == 83

label values statefip fips

drop state
rename intmonth month

sort statefips year month

merge m:1 state year month using mw_state_monthly
keep if _merge == 3 // Note that this keeps years 1979-2012
drop _merge realfedmw fedmw indexedwage eversuperfed lnmin quarter



#delimit ;
label values dind    dind ;  
label define dind    
	1           "Agriculture Service"           
	2           "Other Agriculture"             
	3           "Mining"                        
	4           "Construction"                  
	5           "Lumber and wood products , except furniture"
	6           "Furniture and fixtures"        
	7           "Stone clay ,glass and concrete product"
	8           "Primary metals"                
	9           "Fabricated metal"              
	10          "Not specified metal industries"
	11          "Machinery, except electrical"  
	12          "Electrical Machinery, equipment ,and supplies"
	13          "Motor vehicles and equipment"  
	14          "Aircrafts and parts"           
	15          "Other transportation equipment"
	16          "Professional and photographic equipment"
	17          "Toys, amusements ,and sporting goods"
	18          "Miscellaneous and not specified manufacturing industries"
	19          "Food and kindred products"     
	20          "Tobacco manufactures"          
	21          "Textile mill products"         
	22          "Apparel and other finished textile prod."
        23          "Paper and allied products"
	24          "Printing ,publishing and allied industries"
	25          "Chemicals and allied products" 
	26          "Petroleum and coal products"   
	27          "Rubber and miscellaneous plastics products"
	28          "Leather and leather products"  
	29          "Transportation"                
	30          "Communications"                
	31          "Utilities and Sanitary Services"
	32          "Wholesale Trade"               
	33          "Retail Trade"                  
	34          "Banking and Other Finance"     
	35          "Insurance and Real Estate"     
	36          "Private Household Services"    
	37          "Business Services"             
	38          "Repair Services"               
	39          "Personal Services , Except Private Household"
	40          "Entertainment and Recreation Services"
	41          "Hospitals"                     
	42          "Health Services , Except Hospitals"
	43          "Educational Services"          
	44          "Social Services"               
	45          "Other professional Services"   
	46          "Forestry and Fisheries"        
	51          "Armed Forces last job, currently unemployed"
	52          "Public Administration"         
;

label values dind02    dind02 ;  
label define dind02    
        1            "Agriculture"
        2            "Forestry, logging, fishing, hunting, and trapping"
        3            "Mining"
        4            "Construction"
        5            "Nonmetallic mineral products"
        6            "Primary metals and fabricated metal products"
        7            "Machinery manufacturing"
        8            "Computer and electronic products"
        9            "Electrical equipment, appliance manufacturing"
        10           "Transportation equipment manufacturing"
        11           "Wood products"
        12           "Furniture and fixtures manufacturing"
        13           "Miscellaneous and not specified manufacturing"
        14           "Food manufacturing"
        15           "Beverage and tobacco products"
        16           "Textile, apparel, and leather manufacturing"
        17           "Paper and printing"
        18           "Petroleum and coal products"
        19           "Chemical manufacturing"
        20           "Plastics and rubber products"
        21           "Wholesale trade"
        22           "Retail trade"
        23           "Transportation and warehousing"
        24           "Utilities"
        25           "Publishing industries (except internet)"
        26           "Motion picture and sound recording industries"
        27           "Broadcasting (except internet)"
        28           "Internet publishing and broadcasting"
        29           "Telecommunications"
        30           "Internet service providers and data processing services"
        31           "Other information services"
        32           "Finance"
        33           "Insurance"
        34           "Real Estate"
        35           "Rental and leasing services"
        36           "Professional and Technical services"
        37           "Management of companies and enterprises"
        38           "Administrative and support services"
        39           "Waste management and remediation services"
        40           "Educational services"
        41           "Hospitals"
        42           "Health care services , except hospitals"
        43           "Social assistance"
        44           "Arts, entertainment, and recreation"
        45           "Accomodation"
        46           "Food services and drinking places"
        47           "Repair and maintenance"
        48           "Personal and laundry services"
        49           "Membership associations and organizations"
        50           "Private households"
        51           "Public Administration"
        52           "Armed forces"
;

#delimit cr

label variable dind "NBER industry code for pre-2002"

label variable dind02 "NBER industry code for post-2002"



order statefips censusreg censusdiv year month hhid hhnum lineno relate age race sex ///
weight dind dind02 uhourse paidhre earnhre earnwke educ fullpartnone mw realmw

sort statefips year hhid hhnum lineno

gen byte lemw = 0 if paidhre == 1
replace lemw = 1 if earnhre < mw
label variable lemw "Hourly worker is paid less than state minimum wage"
gen byte atmw = 0 if paidhre == 1
replace atmw = 1 if earnhre == mw
label variable atmw "Hourly worker is paid exactly state minimum wage"
gen byte leatmw = 0 if paidhre == 1
replace leatmw = 1 if earnhre <= mw
label variable leatmw "Hourly worker is paid less than or equal state MW"
gen byte mwp50 = 0 if paidhre == 1
replace mwp50 = 1 if earnhre <= mw + 0.5
label variable mwp50 "Hourly worker is paid within 50c of state MW"
gen byte mwp100 = 0 if paidhre == 1
replace mwp100 = 1 if earnhre <= mw +1.0
label variable mwp100 "Hourly worker is paid within 1 dollar of state MW"

gen leatmw_employed = 0 if fullpartnone > 1
replace leatmw_employed = 1 if leatmw_employed == 0 & leatmw == 1
label variable leatmw_employed "Worker is paid less than or equal state MW (all employed but not imputed)"

compress
save unlinked_morg4,replace


/*
*******

* CLEAN UP intermediate files (Optional)

*******

qui forv y = 1979/2011 {

erase morg`y'_t.dta
erase morg`y'_tplus1.dta
erase personmerged`y'.dta

}

erase morg2012_t.dta
